==> af-common-socket-1.1.17.34-sources.jar: com/af/v4/system/common/socket/SocketServerManager.java <==
package com.af.v4.system.common.socket;

import com.af.v4.system.common.socket.config.SocketConfig;
import com.af.v4.system.common.socket.config.SocketConfigItem;
import com.af.v4.system.common.socket.core.server.SocketServer;
import com.af.v4.system.common.socket.core.server.modbus.ModBusServer;
import com.af.v4.system.common.socket.core.server.tcp.TcpServer;
import com.af.v4.system.common.socket.core.server.udp.UdpServer;
import com.af.v4.system.common.socket.enums.SocketTypeEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Component
public class SocketServerManager {
    private static final Logger LOGGER = LoggerFactory.getLogger(SocketServerManager.class);

    private static final Map<String, SocketConfigItem> socketConfigMap = new HashMap<>();
    private final SocketConfig socketConfig;
    private final List<SocketServer<?, ?>> socketServerList = new ArrayList<>();

    public SocketServerManager(SocketConfig socketConfig) {
        this.socketConfig = socketConfig;
    }

    public static SocketConfigItem getSocketConfigItemByPort(String port) {
        return socketConfigMap.get(port);
    }

    /**
     * 启动socket服务端
     */
    @PostConstruct
    public void startAll() {
        List<SocketConfigItem> socketConfigItemList = socketConfig.getSocketServerList();
        if (socketConfigItemList != null) {
            socketConfigItemList.forEach(item -> {
                SocketServer<?, ?> socketServer = createSocketServer(item);
                socketServerList.add(socketServer);
                item.getPorts().forEach(port -> socketConfigMap.put(port.toString(), item));
                if (socketServer != null) {
                    socketServer.run(item);
                }
            });
        }
    }

    /**
     * 创建SocketServer实例
     */
    private SocketServer<?, ?> createSocketServer(SocketConfigItem item) {
        SocketServer<?, ?> socketServer = null;
        if (item.getType() == SocketTypeEnum.TCP) {
            socketServer = new TcpServer();
        } else if (item.getType() == SocketTypeEnum.UDP) {
            socketServer = new UdpServer();
        } else if (item.getType() == SocketTypeEnum.MODBUS_TCP) {
            socketServer = new ModBusServer();
        }
        return socketServer;
    }

    @PreDestroy
    public void destroyAll() {
        for (SocketServer<?, ?> socketServer : socketServerList) {
            socketServer.destroy();
        }
    }
}

==> af-common-socket-2.0.10-sources.jar: com/af/v4/system/common/socket/SocketServerManager.java <==
package com.af.v4.system.common.socket;

import com.af.v4.system.common.socket.config.SocketConfig;
import com.af.v4.system.common.socket.config.SocketConfigItem;
import com.af.v4.system.common.socket.core.server.SocketServer;
import com.af.v4.system.common.socket.core.server.modbus.ModBusServer;
import com.af.v4.system.common.socket.core.server.tcp.TcpServer;
import com.af.v4.system.common.socket.core.server.udp.UdpServer;
import com.af.v4.system.common.socket.enums.SocketTypeEnum;
import jakarta.annotation.PostConstruct;
import jakarta.annotation.PreDestroy;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Component
public class SocketServerManager {
    private static final Logger LOGGER = LoggerFactory.getLogger(SocketServerManager.class);

    private static final Map<String, SocketConfigItem> socketConfigMap = new HashMap<>();
    private final SocketConfig socketConfig;
    private final List<SocketServer<?, ?>> socketServerList = new ArrayList<>();

    public SocketServerManager(SocketConfig socketConfig) {
        this.socketConfig = socketConfig;
    }

    public static SocketConfigItem getSocketConfigItemByPort(String port) {
        return socketConfigMap.get(port);
    }

    /**
     * 启动socket服务端
     */
    @PostConstruct
    public void startAll() {
        List<SocketConfigItem> socketConfigItemList = socketConfig.getSocketServerList();
        if (socketConfigItemList != null) {
            socketConfigItemList.forEach(item -> {
                SocketServer<?, ?> socketServer = createSocketServer(item);
                socketServerList.add(socketServer);
                item.getPorts().forEach(port -> socketConfigMap.put(port.toString(), item));
                if (socketServer != null) {
                    socketServer.run(item);
                }
            });
        }
    }

    /**
     * 创建SocketServer实例
     */
    private SocketServer<?, ?> createSocketServer(SocketConfigItem item) {
        SocketServer<?, ?> socketServer = null;
        if (item.getType() == SocketTypeEnum.TCP) {
            socketServer = new TcpServer();
        } else if (item.getType() == SocketTypeEnum.UDP) {
            socketServer = new UdpServer();
        } else if (item.getType() == SocketTypeEnum.MODBUS_TCP) {
            socketServer = new ModBusServer();
        }
        return socketServer;
    }

    @PreDestroy
    public void destroyAll() {
        for (SocketServer<?, ?> socketServer : socketServerList) {
            socketServer.destroy();
        }
    }
}
